<?php 

defined( 'ABSPATH' ) or die( 'Keep Quit' );

final class Product_Share{

    /*
     * Version of Plugin.
     *
     */

    protected $_version = '1.0';

    protected static $_instance = null;


    public static function instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }

        return self::$_instance;
    }


    /*
     * Construct of the Class.
     *
     */

    public function __construct(){

        $this->includes();
        $this->init();
        $this->get_backend();
        $this->get_frontend();

    }


    /*
     * Version function.
     *
     */
    public function version() {
        return esc_attr( $this->_version );
    }

    /*
     * Bootstraps the class and hooks required actions & filters.
     *
     */
    public function init() {

        // Load TextDomain
        add_action( 'plugins_loaded', array( $this, 'load_textdomain' ) );
    } 


    /**
     *
     * Load Text Domain Folder
     *
     */
    public function load_textdomain() {
        load_plugin_textdomain( "variation-price-display", false, basename( dirname( __FILE__ ) )."/languages" );
    }

    /*
     * Includes files.
     *
     */

    public function includes() {
        require_once dirname( __FILE__ ) . '/class-product-share-admin-settings.php';
        require_once dirname( __FILE__ ) . '/class-product-share-front.php';
    }

    /**
     *
     * Admin Settings
     *
     */

    public function get_backend(){
        return Product_Share_Admin_Settings::instance();
    }


    /**
     *
     * Frontend 
     *
     */

    public function get_frontend(){
        return Product_Share_Front::instance();
    }


    /**
     *
     * Return all options of Product Share Plugin
     *
     */
    public static function get_options(){

        $get_option = get_option('product_share_option');

        $options = array(

            'display_position' => ( !empty( $get_option['display_position'] ) ) ? $get_option['display_position'] : 'with_category',

            'selected_lables' => ( !empty( $get_option['buttons'] ) ) ? $get_option['buttons'] : apply_filters('selected_lables',array(
                    'facebook' => 'Facebook',
                    'twitter' => 'Twitter',
                    'linkedin' => 'LinkedIn'
                )
            ),

            'labels' => ( !empty( $get_option['all_buttons'] ) ) ? $get_option['all_buttons'] : apply_filters('psfw_labels', array(
                    'facebook' => 'Facebook',
                    'twitter' => 'Twitter',
                    'linkedin' => 'LinkedIn'
                )),

            'icon_appearance' => ( !empty( $get_option['icon_appearance'] ) ) ? $get_option['icon_appearance'] : 'only_icon',

            'button_shape' => ( !empty( $get_option['button_shape'] ) ) ? $get_option['button_shape'] : 'round',

            'copy_to_clipboard' => ( empty( $get_option['copy_to_clipboard'] ) ) ? 0 : $get_option['copy_to_clipboard'],

        );

        return (object) apply_filters( 'psfw_options', $options );
    }
    

}